CLIENT_ID_ENV_VAR = 'APP_CLIENT_ID'
USER_POOL_ID_ENV_VAR = 'POOL_ID'
REGION_ENV_VAR = 'AWS_REGION'
USER_POOL_HANDLER_NAME_ENV_VAR = 'USER_POOL_HANDLER_NAME'
DEFAULT_USER_POOL_HANDLER_NAME = 'UserPoolAuth'
